@@ -1,8 +1,8 @@
 contribution.matrix <- function(x, method, model, hatmatrix.F1000,
                                 verbose = FALSE) {
   if (verbose)
-    cat(paste0("Calculate network contributions (",
-               model, " effects model):\n"))
+    cat("Calculate network contributions (", model, " effects model):\n",
+        sep = "")
   ##
   if (method == "randomwalk")
     return(contribution.matrix.davies(x, model, verbose = verbose))
@@ -104,7 +104,7 @@ contribution.matrix.tpapak <- function(x, model, hatmatrix.F1000,
   ##
   reduceGraph <- function(g, comparison, verbose, is.tictoc) {
     if (verbose)
-      cat(paste0("- ", comparison, "\n"))
+      cat("- ", comparison, "\n", sep = "")
     ##
     if (verbose & is.tictoc)
       tictoc::tic()
@@ -162,7 +162,7 @@ contribution.matrix.tpapak <- function(x, model, hatmatrix.F1000,
   colnames(weights) <- seq_len(dims[2])
   
   
-  is.tictoc <- is.installed.package("tictoc", stop = FALSE)
+  is.tictoc <- is_installed_package("tictoc", stop = FALSE)
   ## rows of comparison matrix
   comparisons <- unlist(lapply(rownames(H), unlist))
   ##
@@ -173,7 +173,7 @@ contribution.matrix.tpapak <- function(x, model, hatmatrix.F1000,
   
   colnames(weights) <- directs
   ##
-  weights[is.zero(weights)] <- 0
+  weights[is_zero(weights)] <- 0
   ##
   attr(weights, "model") <- model
   attr(weights, "hatmatrix.F1000") <- old
@@ -192,7 +192,7 @@ contribution.matrix.davies <- function(x, model, verbose = FALSE) {
   model <- setchar(model, c("common", "random"))
   chklogical(verbose)
   ##
-  is.tictoc <- is.installed.package("tictoc", stop = FALSE)
+  is.tictoc <- is_installed_package("tictoc", stop = FALSE)
   
   
   ##
@@ -234,9 +234,10 @@ contribution.matrix.davies <- function(x, model, verbose = FALSE) {
         tictoc::tic()
       ##
       if (verbose)
-        cat(paste0("- ",
-                   paste(x$trts[t1], x$trts[t2], sep = x$sep.trts),
-                   " (", r, "/", n.comps, ")\n"))
+        cat("- ",
+            paste(x$trts[t1], x$trts[t2], sep = x$sep.trts),
+            " (", r, "/", n.comps, ")\n",
+            sep = "")
       ##
       ## For each row, t1 is the source and t2 is the sink
       ##
@@ -279,7 +280,7 @@ contribution.matrix.davies <- function(x, model, verbose = FALSE) {
       P[t2, ] <- rep(0, n)
       P[t2, t2] <- 1
       ##
-      P[is.zero(P, n = 1000)] <- 0
+      P[is_zero(P, n = 1000)] <- 0
       ##
       ## Find all possible paths
       ##
@@ -329,12 +330,12 @@ contribution.matrix.davies <- function(x, model, verbose = FALSE) {
         tictoc[r] <- as.numeric(tictoc.r$toc) - as.numeric(tictoc.r$tic)
         ##
         if (verbose)
-          cat(paste(round(tictoc[r], 3), "sec elapsed\n"))
+          cat(round(tictoc[r], 3), "sec elapsed\n")
       }
     }
   }
   ##
-  weights[is.zero(weights)] <- 0
+  weights[is_zero(weights)] <- 0
   ##
   weights <- weights[, apply(weights, 2, sum) > 0, drop = FALSE]
   ##
@@ -360,7 +361,7 @@ contribution.matrix.ruecker.cccp <- function (x, model, verbose = FALSE) {
   model <- setchar(model, c("common", "random"))
   chklogical(verbose)
   ##
-  is.tictoc <- is.installed.package("tictoc", stop = FALSE)
+  is.tictoc <- is_installed_package("tictoc", stop = FALSE)
   
   
   H.full <- hatmatrix.aggr(x, model, type = "full")
@@ -413,9 +414,10 @@ contribution.matrix.ruecker.cccp <- function (x, model, verbose = FALSE) {
         tictoc::tic()
       ##
       if (verbose) {
-        cat(paste0("*** ",
-                   paste(x$trts[t1], x$trts[t2], sep = x$sep.trts),
-                   " (", r, " / ", n.comps, ") ***\n"))
+        cat("*** ",
+            paste(x$trts[t1], x$trts[t2], sep = x$sep.trts),
+            " (", r, " / ", n.comps, ") ***\n",
+            sep = "")
       }
       ##
       Q <- matrix(0, nrow = n, ncol = n)
@@ -437,10 +439,10 @@ contribution.matrix.ruecker.cccp <- function (x, model, verbose = FALSE) {
           if (i != j & Q[i, j] <= 0)
             Q[i, j] <- 0
       ##
-      P <- MASS::ginv(diag(rowSums(Q))) %*% Q # Transition matrix
+      P <- ginv(diag(rowSums(Q))) %*% Q # Transition matrix
       P[t2, ] <- rep(0, n)
       P[t2, t2] <- 1
-      P[is.zero(P, n = 1000)] <- 0
+      P[is_zero(P, n = 1000)] <- 0
       Pgraph <-
         igraph::graph_from_adjacency_matrix(
                   P, "directed", weighted = TRUE, diag = FALSE)
@@ -486,11 +488,11 @@ contribution.matrix.ruecker.cccp <- function (x, model, verbose = FALSE) {
       ## Find LS solution phi0.r
       ##
       path.length <- rowSums(abs(Z))
-      phi0.r <- H.full[r, ] %*% MASS::ginv(Z)
+      phi0.r <- H.full[r, ] %*% ginv(Z)
       ##
       ## Find L1 solution
       ##
-      A <- diag(p) - Z %*% MASS::ginv(Z)
+      A <- diag(p) - Z %*% ginv(Z)
       ##
       ## Minimise |wA + phi0.r|
       ##
@@ -510,13 +512,13 @@ contribution.matrix.ruecker.cccp <- function (x, model, verbose = FALSE) {
         tictoc[r] <- as.numeric(tictoc.r$toc) - as.numeric(tictoc.r$tic)
         ##
         if (verbose)
-          cat(paste(round(tictoc[r], 3), "sec elapsed\n"))
+          cat(round(tictoc[r], 3), "sec elapsed\n")
       }
     }
   }
   ##
   w <- weights
-  weights[is.zero(weights)] <- 0
+  weights[is_zero(weights)] <- 0
   weights <- weights[, apply(weights, 2, sum) > 0, drop = FALSE]
   attr(weights, "model") <- model
   
@@ -536,7 +538,7 @@ contribution.matrix.ruecker.pseudoinv <- function (x, model, verbose = FALSE) {
   model <- setchar(model, c("common", "random"))
   chklogical(verbose)
   ##
-  is.tictoc <- is.installed.package("tictoc", stop = FALSE)
+  is.tictoc <- is_installed_package("tictoc", stop = FALSE)
   
   
   ##
@@ -590,9 +592,10 @@ contribution.matrix.ruecker.pseudoinv <- function (x, model, verbose = FALSE) {
         tictoc::tic()
       ##
       if (verbose)
-        cat(paste0("- ",
-                   paste(x$trts[t1], x$trts[t2], sep = x$sep.trts),
-                   " (", r, "/", n.comps, ")\n"))
+        cat("- ",
+            paste(x$trts[t1], x$trts[t2], sep = x$sep.trts),
+            " (", r, "/", n.comps, ")\n",
+            sep = "")
       ##
       ## For each row, t1 is the source and t2 is the sink
       ##
@@ -632,11 +635,11 @@ contribution.matrix.ruecker.pseudoinv <- function (x, model, verbose = FALSE) {
       ## Create the transition matrix by normalising the values in
       ## each row of Q
       ##
-      P <- MASS::ginv(diag(rowSums(Q))) %*% Q
+      P <- ginv(diag(rowSums(Q))) %*% Q
       P[t2, ] <- rep(0, n)
       P[t2, t2] <- 1
       ##
-      P[is.zero(P, n = 1000)] <- 0
+      P[is_zero(P, n = 1000)] <- 0
       ##
       ## Find all possible paths
       ##
@@ -683,7 +686,7 @@ contribution.matrix.ruecker.pseudoinv <- function (x, model, verbose = FALSE) {
       ## phi %*% Z = H.full[r, ]
       ##
       path.length <- rowSums(abs(Z))
-      phi.r <- H.full[r, ] %*% MASS::ginv(Z)
+      phi.r <- H.full[r, ] %*% ginv(Z)
       weights[r, ] <- (phi.r / path.length) %*% abs(Z)
       phi[[r]] <- as.vector(phi.r)
       pl[[r]] <- path.length
@@ -693,13 +696,13 @@ contribution.matrix.ruecker.pseudoinv <- function (x, model, verbose = FALSE) {
         tictoc[r] <- as.numeric(tictoc.r$toc) - as.numeric(tictoc.r$tic)
         ##
         if (verbose)
-          cat(paste(round(tictoc[r], 3), "sec elapsed\n"))
+          cat(round(tictoc[r], 3), "sec elapsed\n")
       }
     }
   }
   ##  
   w <- weights
-  weights[is.zero(weights)] <- 0
+  weights[is_zero(weights)] <- 0
   weights <- weights[, apply(weights, 2, sum) > 0, drop = FALSE]
   attr(weights, "model") <- model
   
