@@ -50,11 +50,10 @@
 #' @method netgraph netconnection
 #' @export
 
-
 netgraph.netconnection <- function(x, seq,
                                    col = seq_len(x$n.subnets),
                                    reference.group = NULL,
-                                   plastic = FALSE,
+                                   plastic = gs("plastic"),
                                    ...) {
   
   
