@@ -7,9 +7,10 @@
 #' 
 #' @aliases netleague print.netleague
 #' 
-#' @param x An object of class \code{netmeta} or \code{netleague}
-#'   (mandatory).
-#' @param y An object of class \code{netmeta} (optional).
+#' @param x An object of created with \code{netmeta}, \code{netcomb},
+#'   \code{discomb}, or \code{netleague} (mandatory).
+#' @param y An object of class \code{netmeta}, \code{netcomb}, or \code{discomb}
+#'   (optional).
 #' @param common A logical indicating whether a league table should be
 #'   printed for the common effects network meta-analysis.
 #' @param random A logical indicating whether a league table should be
@@ -22,9 +23,12 @@
 #'   should be back transformed. If \code{backtransf = TRUE}, results
 #'   for \code{sm = "OR"} are printed as odds ratios rather than log
 #'   odds ratios, for example.
-#' @param direct A logical indicating whether league table with
-#'   network estimates (default) or estimates from direct comparisons
-#'   should be generated if argument \code{y} is not missing.
+#' @param direct A logical indicating whether league tables with
+#'   network estimates or estimates from direct comparisons
+#'   should be shown if (i) argument \code{y} is provided and the input for
+#'   arguments \code{x} and \code{y} was created with \code{netmeta} or (ii)
+#'   input for argument \code{x} was created with \code{netmeta} or
+#'   \code{netcomb}.
 #' @param digits Minimal number of significant digits, see
 #'   \code{print.default}.
 #' @param big.mark A character used as thousands separator.
@@ -43,6 +47,8 @@
 #'   file.
 #' @param overwrite A logical indicating whether an existing Excel
 #'   file should be overwritten.
+#' @param details A logical specifying whether details on rows and columns
+#'   should be printed.
 #' @param warn.deprecated A logical indicating whether warnings should
 #'   be printed if deprecated arguments are used.
 #' @param \dots Additional arguments (passed on to \code{write_xlsx}
@@ -53,24 +59,36 @@
 #' in a network meta-analysis (Hutton et al., 2015). Typically, both
 #' treatment estimates and confidence intervals are shown.
 #' 
-#' If argument \code{y} is not provided, the league table contains the
-#' network estimates from network meta-analysis object \code{x} in the
-#' lower triangle and the direct treatment estimates from pairwise
-#' comparisons in the upper triangle. Note, for the random-effects
-#' model, the direct treatment estimates are based on the common
-#' between-study variance \eqn{\tau^2} from the network meta-analysis,
-#' i.e. the square of list element \code{x$tau}.
+#' If argument \code{y} is not provided, the league table contains
+#' \itemize{
+#' \item the network estimates in the lower triangle and the direct treatment
+#'   estimates from pairwise comparisons in the upper triangle, if the input
+#'   for argument \code{x} was created with \code{netmeta};
+#' \item the network estimates from the component network meta-analysis in the
+#'   lower triangle, if the input for argument \code{x} was created with
+#'   \code{netcomb}, and, in the upper triangle, (i) the network estimates from
+#'   the network meta-analysis, if argument \code{direct = FALSE}, or
+#'   (ii)) the direct treatment estimates from pairwise comparisons, if
+#'   argument \code{direct = TRUE};
+#' \item the network estimates from the component network meta-analysis in the
+#'   lower and upper triangle, if the input for argument \code{x} was created
+#'   with \code{discomb}.
+#' }
+#' Note, for the random-effects model, the direct treatment estimates are based
+#' on the common between-study variance \eqn{\tau^2} from the network
+#' meta-analysis, i.e. the square of list element \code{x$tau}.
 #' 
 #' If argument \code{y} is provided, the league table contains
-#' information on treatment comparisons from network meta-analysis
-#' object \code{x} in the lower triangle and from network
+#' information on treatment comparisons from (component) network meta-analysis
+#' object \code{x} in the lower triangle and from (component) network
 #' meta-analysis object \code{y} in the upper triangle. This is, for
 #' example, useful to print information on efficacy and safety in the
-#' same league table.
+#' same league table. If argument \code{direct = TRUE}, direct estimates are
+#' shown both in the lower and upper triangle if the input for arguments
+#' \code{x} and \code{y} was created with \code{netmeta}.
 #'
-#' By default, an R object with the league tables is
-#' generated. Alternatively, an Excel file is created if argument
-#' \code{writexl = TRUE}.
+#' By default, an R object with the league tables is generated. Alternatively,
+#' an Excel file is created if argument \code{writexl = TRUE}.
 #' 
 #' This implementation reports pairwise comparisons of the treatment
 #' in the column versus the treatment in the row in the lower triangle
@@ -85,7 +103,7 @@
 #' triangle, e.g., A versus B in the first row and second column and B
 #' versus A in the second row and first column.
 #' 
-#' If the same network meta-analysis object is used for arguments
+#' If the same (component) network meta-analysis object is used for arguments
 #' \code{x} and \code{y}, reciprocal treatment estimates will be shown
 #' in the upper triangle (see examples), e.g., the comparison B versus
 #' A.
@@ -103,8 +121,10 @@
 #' @author Guido Schwarzer \email{guido.schwarzer@@uniklinik-freiburg.de}, Gerta
 #'   Rücker \email{gerta.ruecker@@uniklinik-freiburg.de}
 #' 
-#' @seealso \code{\link{netmeta}}, \code{\link{netposet}},
-#'   \code{\link{netrank}}
+#' @seealso \code{\link{netmeta}}, \code{\link{netcomb}},
+#'   \code{\link{discomb}}, \code{\link{netposet}}, \code{\link{netrank}},
+#'   \code{\link[metadat]{dat.woods2010}},
+#'   \code{\link[metadat]{dat.linde2015}}
 #'
 #' 
 #' @references
@@ -120,10 +140,8 @@
 #' @examples
 #' # Network meta-analysis of count mortality statistics
 #' #
-#' data(Woods2010)
-#' 
 #' p0 <- pairwise(treatment, event = r, n = N,
-#'   studlab = author, data = Woods2010, sm = "OR")
+#'   studlab = author, data = dat.woods2010, sm = "OR")
 #' net0 <- netmeta(p0)
 #' 
 #' oldopts <- options(width = 100)
@@ -156,16 +174,13 @@
 #' # Create Excel files with league tables
 #' # (if R package writexl is available)
 #' #
-#' netleague(net0, digits = 2, bracket = "(", separator = " to ",
-#'           path = tempfile(fileext = ".xlsx"))
+#' if (requireNamespace("writexl", quietly = TRUE))
+#'   netleague(net0, digits = 2, bracket = "(", separator = " to ",
+#'             path = tempfile(fileext = ".xlsx"))
 #' }
 #' 
 #' \donttest{
-#' # Use depression dataset
-#' #
-#' data(Linde2015)
-#' 
-#' # Define order of treatments
+#' # Define order of treatments in depression dataset dat.linde2015
 #' #
 #' trts <- c("TCA", "SSRI", "SNRI", "NRI",
 #'   "Low-dose SARI", "NaSSa", "rMAO-A", "Hypericum", "Placebo")
@@ -178,7 +193,7 @@
 #' #
 #' p1 <- pairwise(treat = list(treatment1, treatment2, treatment3),
 #'   event = list(resp1, resp2, resp3), n = list(n1, n2, n3),
-#'   studlab = id, data = Linde2015, sm = "OR")
+#'   studlab = id, data = dat.linde2015, sm = "OR")
 #' #
 #' net1 <- netmeta(p1, common = FALSE,
 #'                 seq = trts, ref = "Placebo", small = "undesirable")
@@ -187,7 +202,7 @@
 #' #
 #' p2 <- pairwise(treat = list(treatment1, treatment2, treatment3),
 #'   event = list(remi1, remi2, remi3), n = list(n1, n2, n3),
-#'   studlab = id, data = Linde2015, sm = "OR")
+#'   studlab = id, data = dat.linde2015, sm = "OR")
 #' #
 #' net2 <- netmeta(p2, common = FALSE,
 #'                 seq = trts, ref = "Placebo", small = "undesirable")
@@ -207,8 +222,8 @@
 #' netleague(net1, net2, seq = netrank(net1), ci = FALSE)
 #' netleague(net1, net2, seq = netrank(net2), ci = FALSE)
 #' 
-#' print(netrank(net1))
-#' print(netrank(net2))
+#' netrank(net1)
+#' netrank(net2)
 #' 
 #' 
 #' # Report results for network meta-analysis twice
@@ -225,21 +240,19 @@
 #' # Generate a partial order of treatment rankings 
 #' #
 #' np <- netposet(net1, net2, outcomes = outcomes)
-#'
-#' # Requires R package 'hasse'
-#' #
-#' hasse(np)
 #' plot(np)
+#'
+#' if (requireNamespace("hasseDiagram", quietly = TRUE))
+#'   hasse(np)
 #' }
 #' 
 #' @rdname netleague
 #' @export netleague
 
-
 netleague <- function(x, y,
                       common = x$common, random = x$random,
-                      seq = x$seq, ci = TRUE, backtransf = TRUE,
-                      direct = FALSE,
+                      seq = x$seq, ci = TRUE, backtransf = x$backtransf,
+                      direct,
                       ##
                       digits = gs("digits"),
                       ##
@@ -254,7 +267,9 @@ netleague <- function(x, y,
                       writexl = !missing(path),
                       path = "leaguetable.xlsx",
                       overwrite = FALSE,
-                      ##
+                      #
+                      details = gs("details"),
+                      #
                       warn.deprecated = gs("warn.deprecated"),
                       ...) {
   
@@ -264,41 +279,75 @@ netleague <- function(x, y,
   ## (1) Check class and arguments
   ##
   ##
-  chkclass(x, "netmeta")
+  
+  chkclass(x, c("netmeta", "netcomb"))
   x <- updateversion(x)
-  ##
-  if (!missing(y)) {
-    chkclass(y, "netmeta")
+  #
+  x.netmeta <- inherits(x, "netmeta")
+  x.discomb <- inherits(x, "discomb")
+  x.netcomb <- !(x.netmeta | x.discomb)
+  #
+  x.is.y <- FALSE
+  #
+  avail.y <- !missing(y)
+  #
+  if (avail.y) {
+    chkclass(y, c("netmeta", "netcomb"))
     ##
     if (length(x$seq) != length(y$seq))
       stop("Arguments 'x' and 'y' must have the same number of treatments.")
     if (any(sort(x$seq) != sort(y$seq)))
       stop("Arguments 'x' and 'y' must have the same treatments.")
-    ##
+    #
+    y.netmeta <- inherits(y, "netmeta")
+    y.discomb <- inherits(y, "discomb")
+    y.netcomb <- !(y.netmeta | y.discomb)
+    #
     x.is.y <- all.equal(x, y)
     x.is.y <- is.logical(x.is.y) && x.is.y
   }
-  ##
+  #
   if (missing(seq)) {
-    seq.f <- seq.r <- seq
+    seq.c <- seq.r <- seq
   }
   else {
     if (is.null(seq))
       stop("Argument 'seq' must be not NULL.")
     else if (inherits(seq, "netrank")) {
-      ranking.f <- seq$ranking.common
+      ranking.c <- seq$ranking.common
       ranking.r <- seq$ranking.random
       ##
-      seq.f <- setseq(names(ranking.f)[rev(order(ranking.f))], x$seq)
+      seq.c <- setseq(names(ranking.c)[rev(order(ranking.c))], x$seq)
       seq.r <- setseq(names(ranking.r)[rev(order(ranking.r))], x$seq)
     }
     else
-      seq.f <- seq.r <- setseq(seq, x$seq)
+      seq.c <- seq.r <- setseq(seq, x$seq)
   }
   ##
   chklogical(ci)
+  #
   chklogical(backtransf)
+  #
+  if (missing(direct)) {
+    if (!avail.y)
+      direct <- !x.discomb
+    else
+      direct <- FALSE
+  }
   chklogical(direct)
+  #
+  if (direct &&
+      (inherits(x, "discomb") || (avail.y && inherits(y, "discomb")))) {
+    warning("Argument 'direct' set to FALSE for object created with discomb().")
+    direct <- FALSE
+  }
+  #
+  if (!direct && (inherits(x, "netmeta")) && !avail.y) {
+    warning(paste("Argument 'direct' set to TRUE for single object",
+                  "created with netmeta()."))
+    direct <- TRUE
+  }
+  #
   chknumeric(digits, min = 0, length = 1)
   ##
   chkchar(text.NA)
@@ -316,6 +365,8 @@ netleague <- function(x, y,
   chklogical(writexl)
   chkchar(path, length = 1)
   chklogical(overwrite)
+  #
+  chklogical(details)
   ##
   ## Check for deprecated arguments in '...'
   ##
@@ -334,151 +385,275 @@ netleague <- function(x, y,
   chklogical(random)
   
   
+  #
+  #
+  # (2) Set details
+  #
+  #
+  
+  if (details) {
+    if (x.netmeta) {
+      if (avail.y & direct)
+        txt.x <- "\nLower triangle: results from direct comparisons"
+      else
+        txt.x <- "\nLower triangle: results from network meta-analysis"
+    }
+    else
+      txt.x <- "\nLower triangle: results from component network meta-analysis"
+    #
+    if (avail.y) {
+      if (y.netmeta) {
+        if (direct)
+          txt.y <- "\nUpper triangle: results from direct comparisons"
+        else
+          txt.y <- "\nUpper triangle: results from network meta-analysis"
+      }
+      else
+        txt.y <-
+          "\nUpper triangle: results from component network meta-analysis"
+    }
+    else {
+      if (x.netmeta)
+        txt.y <- "\nUpper triangle: results from direct comparisons"
+      else if (x.netcomb) {
+        if (direct)
+          txt.y <- "\nUpper triangle: results from direct comparisons"
+        else
+          txt.y <- "\nUpper triangle: results from network meta-analysis"
+      }
+      else {
+          txt.y <-
+            "\nUpper triangle: results from component network meta-analysis"
+      }
+    }    
+    #
+    txt.x <- paste(txt.x, "(column vs row)")
+    txt.y <- paste(txt.y,
+                   if (x.discomb & !avail.y)
+                     "(column vs row)"
+                   else if (!avail.y | (avail.y & !x.is.y)) "(row vs column)"
+                   else "(column vs row)")
+    #
+    text.details <- paste0(txt.x, txt.y, "\n")
+  }
+  else
+    text.details <- NULL
+  
+  
   ##
   ##
-  ## (2) Back-transform log odds ratios & Co
+  ## (3) Values in lower triangle
   ##
   ##
-  if (!missing(y) & direct) {
+  
+  if (x.netmeta & avail.y & direct) {
     TE.common.x    <- x$TE.direct.common
     lower.common.x <- x$lower.direct.common
     upper.common.x <- x$upper.direct.common
-    ##
-    if (random) {
-      TE.random.x    <- x$TE.direct.random
-      lower.random.x <- x$lower.direct.random
-      upper.random.x <- x$upper.direct.random
-    }
+    #
+    TE.random.x    <- x$TE.direct.random
+    lower.random.x <- x$lower.direct.random
+    upper.random.x <- x$upper.direct.random
+  }
+  else if (x.netcomb & avail.y & direct) {
+    TE.common.x    <- x$x$TE.direct.common
+    lower.common.x <- x$x$lower.direct.common
+    upper.common.x <- x$x$upper.direct.common
+    #
+    TE.random.x    <- x$x$TE.direct.random
+    lower.random.x <- x$x$lower.direct.random
+    upper.random.x <- x$x$upper.direct.random
   }
   else {
     TE.common.x    <- x$TE.common
     lower.common.x <- x$lower.common
     upper.common.x <- x$upper.common
-    ##
-    if (random) {
-      TE.random.x    <- x$TE.random
-      lower.random.x <- x$lower.random
-      upper.random.x <- x$upper.random
+    #
+    TE.random.x    <- x$TE.random
+    lower.random.x <- x$lower.random
+    upper.random.x <- x$upper.random
+  }
+  
+  
+  #
+  #
+  # (4) Values in upper triangle
+  #
+  #
+  
+  if (!avail.y) {
+    if (x.netmeta) {
+      TE.common.y    <- x$TE.direct.common
+      lower.common.y <- x$lower.direct.common
+      upper.common.y <- x$upper.direct.common
+      #
+      TE.random.y    <- x$TE.direct.random
+      lower.random.y <- x$lower.direct.random
+      upper.random.y <- x$upper.direct.random
+    }
+    else if (inherits(x, "discomb")) {
+      TE.common.y    <- x$TE.common
+      lower.common.y <- x$lower.common
+      upper.common.y <- x$upper.common
+      #
+      TE.random.y    <- x$TE.random
+      lower.random.y <- x$lower.random
+      upper.random.y <- x$upper.random
+    }
+    else {
+      if (direct) {
+        TE.common.y    <- x$x$TE.direct.common
+        lower.common.y <- x$x$lower.direct.common
+        upper.common.y <- x$x$upper.direct.common
+        #
+        TE.random.y    <- x$x$TE.direct.random
+        lower.random.y <- x$x$lower.direct.random
+        upper.random.y <- x$x$upper.direct.random
+      }
+      else {
+        TE.common.y    <- x$x$TE.common
+        lower.common.y <- x$x$lower.common
+        upper.common.y <- x$x$upper.common
+        #
+        TE.random.y    <- x$x$TE.random
+        lower.random.y <- x$x$lower.random
+        upper.random.y <- x$x$upper.random
+      }
     }
   }
-  ##
-  if (backtransf & is.relative.effect(x$sm)) {
-    TE.common.x    <- exp(TE.common.x)
-    lower.common.x <- exp(lower.common.x)
-    upper.common.x <- exp(upper.common.x)
-    ##
-    if (random) {
-      TE.random.x    <- exp(TE.random.x)
-      lower.random.x <- exp(lower.random.x)
-      upper.random.x <- exp(upper.random.x)
-    }
-  }
-  ##
-  if (!missing(y)) {
-    if (direct) {
+  else {
+    if (y.netmeta & direct) {
       TE.common.y    <- y$TE.direct.common
       lower.common.y <- y$lower.direct.common
       upper.common.y <- y$upper.direct.common
-      ##
-      if (random) {
-        TE.random.y    <- y$TE.direct.random
-        lower.random.y <- y$lower.direct.random
-        upper.random.y <- y$upper.direct.random
-      }
+      #
+      TE.random.y    <- y$TE.direct.random
+      lower.random.y <- y$lower.direct.random
+      upper.random.y <- y$upper.direct.random
+    }
+    else if (y.netcomb & direct) {
+      TE.common.y    <- y$x$TE.direct.common
+      lower.common.y <- y$x$lower.direct.common
+      upper.common.y <- y$x$upper.direct.common
+      #
+      TE.random.y    <- y$x$TE.direct.random
+      lower.random.y <- y$x$lower.direct.random
+      upper.random.y <- y$x$upper.direct.random
     }
     else {
       TE.common.y    <- y$TE.common
       lower.common.y <- y$lower.common
       upper.common.y <- y$upper.common
-      ##
-      if (random) {
-        TE.random.y    <- y$TE.random
-        lower.random.y <- y$lower.random
-        upper.random.y <- y$upper.random
-      }
-    }
-    ##
-    if (backtransf & is.relative.effect(y$sm)) {
-      TE.common.y    <- exp(TE.common.y)
-      lower.common.y <- exp(lower.common.y)
-      upper.common.y <- exp(upper.common.y)
-      ##
-      if (random) {
-        TE.random.y    <- exp(TE.random.y)
-        lower.random.y <- exp(lower.random.y)
-        upper.random.y <- exp(upper.random.y)
-      }
-    }
-    ##
-    if (x.is.y) {
-      TE.common.y    <- t(TE.common.y)
-      lower.common.y <- t(lower.common.y)
-      upper.common.y <- t(upper.common.y)
-      ##
-      if (random) {
-        TE.random.y    <- t(TE.random.y)
-        lower.random.y <- t(lower.random.y)
-        upper.random.y <- t(upper.random.y)
-      }
+      #
+      TE.random.y    <- y$TE.random
+      lower.random.y <- y$lower.random
+      upper.random.y <- y$upper.random
     }
   }
-  else {
-    if (backtransf & is.relative.effect(x$sm)) {
-      TE.common.y    <- exp(x$TE.direct.common)
-      lower.common.y <- exp(x$lower.direct.common)
-      upper.common.y <- exp(x$upper.direct.common)
-      ##
-      if (random) {
-        TE.random.y    <- exp(x$TE.direct.random)
-        lower.random.y <- exp(x$lower.direct.random)
-        upper.random.y <- exp(x$upper.direct.random)
-      }
-    }
-    else {
-      TE.common.y    <- x$TE.direct.common
-      lower.common.y <- x$lower.direct.common
-      upper.common.y <- x$upper.direct.common
-      ##
-      if (random) {
-        TE.random.y    <- x$TE.direct.random
-        lower.random.y <- x$lower.direct.random
-        upper.random.y <- x$upper.direct.random
-      }
-    }
-  }
-  ##
-  ## Comparisons are column versus row
-  ##
-  TE.common.x <- t(TE.common.x)
-  lower.common.x <- t(lower.common.x)
-  upper.common.x <- t(upper.common.x)
-  ##
-  if (random) {
-    TE.random.x <- t(TE.random.x)
-    lower.random.x <- t(lower.random.x)
-    upper.random.x <- t(upper.random.x)
-  }
-  ##
-  TE.common.y <- t(TE.common.y)
-  lower.common.y <- t(lower.common.y)
-  upper.common.y <- t(upper.common.y)
-  ##
-  if (random) {
-    TE.random.y <- t(TE.random.y)
+  #
+  if (x.is.y | (x.discomb & !avail.y)) {
+    TE.common.y    <- t(TE.common.y)
+    lower.common.y <- t(lower.common.y)
+    upper.common.y <- t(upper.common.y)
+    #
+    TE.random.y    <- t(TE.random.y)
     lower.random.y <- t(lower.random.y)
     upper.random.y <- t(upper.random.y)
   }
   
   
-  ##
-  ##
-  ## (3) Create league table for common effects model
-  ##
-  ##
-  TE.common.x    <- round(   TE.common.x[seq.f, seq.f], digits)
-  lower.common.x <- round(lower.common.x[seq.f, seq.f], digits)
-  upper.common.x <- round(upper.common.x[seq.f, seq.f], digits)
-  ##
+  #
+  #
+  # (5) Back-transform results
+  #
+  #
+  
+  if (backtransf) {
+    TE.common.x    <- backtransf(TE.common.x, x$sm)
+    lower.common.x <- backtransf(lower.common.x, x$sm)
+    upper.common.x <- backtransf(upper.common.x, x$sm)
+    #
+    # Switch lower and upper limit for VE if results have been
+    # backtransformed
+    #
+    if (x$sm == "VE") {
+      tmp.l <- lower.common.x
+      lower.common.x <- upper.common.x
+      upper.common.x <- tmp.l
+    }
+    #
+    if (random) {
+      TE.random.x    <- backtransf(TE.random.x, x$sm)
+      lower.random.x <- backtransf(lower.random.x, x$sm)
+      upper.random.x <- backtransf(upper.random.x, x$sm)
+      #
+      if (x$sm == "VE") {
+        tmp.l <- lower.random.x
+        lower.random.x <- upper.random.x
+        upper.random.x <- tmp.l
+      }
+    }
+    #
+    TE.common.y    <- backtransf(TE.common.y, x$sm)
+    lower.common.y <- backtransf(lower.common.y, x$sm)
+    upper.common.y <- backtransf(upper.common.y, x$sm)
+    #
+    # Switch lower and upper limit for VE if results have been
+    # backtransformed
+    #
+    if (x$sm == "VE") {
+      tmp.l <- lower.common.y
+      lower.common.y <- upper.common.y
+      upper.common.y <- tmp.l
+    }
+    #
+    if (random) {
+      TE.random.y    <- backtransf(TE.random.y, x$sm)
+      lower.random.y <- backtransf(lower.random.y, x$sm)
+      upper.random.y <- backtransf(upper.random.y, x$sm)
+      #
+      if (x$sm == "VE") {
+        tmp.l <- lower.random.y
+        lower.random.y <- upper.random.y
+        upper.random.y <- tmp.l
+      }
+    }
+  }
+  
+  
+  #
+  #
+  # (6) Comparisons are column versus row
+  #
+  #
+  
+  TE.common.x <- t(TE.common.x)
+  lower.common.x <- t(lower.common.x)
+  upper.common.x <- t(upper.common.x)
+  #
+  TE.random.x <- t(TE.random.x)
+  lower.random.x <- t(lower.random.x)
+  upper.random.x <- t(upper.random.x)
+  #
+  TE.common.y <- t(TE.common.y)
+  lower.common.y <- t(lower.common.y)
+  upper.common.y <- t(upper.common.y)
+  #
+  TE.random.y <- t(TE.random.y)
+  lower.random.y <- t(lower.random.y)
+  upper.random.y <- t(upper.random.y)
+  
+  
+  #
+  #
+  # (7) Create league table for common effects model
+  #
+  #
+  
+  TE.common.x    <- round(   TE.common.x[seq.c, seq.c], digits)
+  lower.common.x <- round(lower.common.x[seq.c, seq.c], digits)
+  upper.common.x <- round(upper.common.x[seq.c, seq.c], digits)
+  #
   if (ci) {
     nl.NA <- is.na(TE.common.x)
     nl.c <- paste(formatN(TE.common.x, digits = digits,
@@ -494,9 +669,9 @@ netleague <- function(x, y,
   nl.c <- matrix(nl.c, nrow = nrow(TE.common.x), ncol = ncol(TE.common.x))
   diag(nl.c) <- rownames(TE.common.x)
   ##
-  TE.common.y    <- round(   TE.common.y[seq.f, seq.f], digits)
-  lower.common.y <- round(lower.common.y[seq.f, seq.f], digits)
-  upper.common.y <- round(upper.common.y[seq.f, seq.f], digits)
+  TE.common.y    <- round(   TE.common.y[seq.c, seq.c], digits)
+  lower.common.y <- round(lower.common.y[seq.c, seq.c], digits)
+  upper.common.y <- round(upper.common.y[seq.c, seq.c], digits)
   ##
   if (ci) {
     nl.NA <- is.na(TE.common.y)
@@ -516,13 +691,16 @@ netleague <- function(x, y,
   nl.c[upper.tri(nl.c)] <- t(nl.c.y)[upper.tri(nl.c)]
   ##
   nl.c <- as.data.frame(nl.c, stringsAsFactors = FALSE)
+  #
+  names(nl.c) <- rownames(nl.c) <- seq.c
   
   
-  ##
-  ##
-  ## (4) Create league table for random effects model
-  ##
-  ##
+  #
+  #
+  # (8) Create league table for random effects model
+  #
+  #
+  
   if (random) {
     TE.random.x    <- round(   TE.random.x[seq.r, seq.r], digits)
     lower.random.x <- round(lower.random.x[seq.r, seq.r], digits)
@@ -563,14 +741,17 @@ netleague <- function(x, y,
     nl.r[upper.tri(nl.r)] <- t(nl.r.y)[upper.tri(nl.c)]
     ##
     nl.r <- as.data.frame(nl.r, stringsAsFactors = FALSE)
+    #
+    names(nl.r) <- rownames(nl.r) <- seq.r
   }
-
-
-  ##
-  ##
-  ## (5) Save Excel file
-  ##
-  ##
+  
+  
+  #
+  #
+  # (9) Save Excel file
+  #
+  #
+  
   if (writexl) {
     if (!(common | random)) {
       warning("Excel file not generated as neither ",
@@ -578,7 +759,7 @@ netleague <- function(x, y,
       return(invisible(NULL))
     }
     ##
-    if (!is.installed.package("writexl", stop = FALSE))
+    if (!is_installed_package("writexl", stop = FALSE))
       stop(paste0("Package 'writexl' missing.",
                   "\n  ",
                   "Please use the following R command for installation:",
@@ -606,39 +787,35 @@ netleague <- function(x, y,
   }
   
   
-  ##
-  ##
-  ## (6) Return league tables
-  ##
-  ##
-  res <- list(common = nl.c,
-              random = if (random) nl.r else NA,
+  #
+  #
+  # (10) Return league tables
+  #
+  #
+  
+  res <- list(common = nl.c, random = if (random) nl.r else NA,
               seq = seq, ci = ci, backtransf = backtransf,
               x = list(common = common, random = random),
+              details = text.details,
+              direct = direct,
               digits = digits,
               version = packageDescription("netmeta")$Version)
-  ##
-  ##
-  ## Backward compatibility
-  ##
+  #
+  # Backward compatibility
+  #
   res$fixed <- res$common
   res$x$fixed <- res$x$common
   ##
   class(res) <- "netleague"
   
-  
   res
 }
 
 
-
-
-
 #' @rdname netleague
 #' @method print netleague
 #' @export
 
-
 print.netleague <- function(x,
                             common = x$x$common,
                             random = x$x$random,
@@ -700,6 +877,8 @@ print.netleague <- function(x,
              collab = rep("", ncol(x$random)))
   }
   
+  if (!is.null(x$details))
+    cat(x$details)
   
   invisible(NULL)
 }
