@@ -52,7 +52,6 @@
 #' @method print decomp.design
 #' @export
 
-
 print.decomp.design <- function(x,
                                 digits.Q = gs("digits.Q"),
                                 showall = FALSE,
@@ -62,7 +61,7 @@ print.decomp.design <- function(x,
                                 big.mark = gs("big.mark"),
                                 nchar.trts = x$nchar.trts,
                                 sort = TRUE,
-                                legend = TRUE,
+                                legend = gs("legend"),
                                 ...) {
   
   
@@ -96,7 +95,7 @@ print.decomp.design <- function(x,
     ##
     dimnames(Qdata) <- list("", c("Q", "d.f.", "p-value"))
     ##
-    cat(paste0("\nTest of inconsistency (between designs):\n"))
+    cat("\nTest of inconsistency (between designs):\n")
     prmatrix(Qdata, quote = FALSE, right = TRUE, ...)
     ##
     return(invisible(NULL))
@@ -179,10 +178,10 @@ print.decomp.design <- function(x,
   }
   
   if (nrow(Q.detach) > 0) {
-    cat(paste0("\nBetween-designs Q statistic after detaching of ",
-               "single designs\n",
-               "(influential designs have p-value markedly different from ",
-               rmSpace(Q.decomp[3, 3]), ")\n\n"))
+    cat("\nBetween-designs Q statistic after detaching of single designs\n",
+        "(influential designs have p-value markedly different from ",
+        rmSpace(Q.decomp[3, 3]), ")\n\n",
+        sep = "")
     ##
     trts2 <- unique(sort(unlist(compsplit(Q.detach[, 1], sep.trts))))
     Q.detach[, 1] <- comps(Q.detach[, 1], trts2, sep.trts, nchar.trts)
@@ -192,11 +191,11 @@ print.decomp.design <- function(x,
     prmatrix(Q.detach, quote = FALSE, right = TRUE)
   }
 
-  cat(paste("\nQ statistic to assess consistency under the assumption of\n",
-            "a full design-by-treatment interaction random effects model\n\n",
-            sep = ""))
+  cat("\nQ statistic to assess consistency under the assumption of\n",
+      "a full design-by-treatment interaction random effects model\n\n",
+      sep = "")
   print(Q.inc.random)
-  
+    
   
   ##
   ## Add legend with abbreviated treatment labels
